/*
 * File:   dg2313w.h                                                        
 * dg2313w.h - библиотека для Ардуино для работы с 1-wire устройством DGB2313  *
 * Дополнительную информацию можно посмотреть на странице                      *
 * https://www.digect.ru/article/dgb113-02                                     *
 * Created Date: Monday February 18th 2019                                     *
 * Author: Potocky Vyacheslav                                                  *
 * -----                                                                       *
 * Last Modified: Monday February 18th 2019 9:07:30 am                         *
 * Modified By:   Potocky Vyacheslav at <slava@potocky.ru>                     *
 * -----                                                                       *
 * Copyright (c) 2019 Digect.RU                                                *
 */
#ifndef DG2313W_H
#define DG2313W_H
#include <inttypes.h>
#include "OneWire.h"

#if ARDUINO >= 100
#include "Arduino.h"
#else
#include "WProgram.h"
#include "pins_arduino.h"
#endif

#define WRITE_ROM  0x1F 
#define READ_ROM   0x20

#define PORT_FLAG  0x09

#define PORT_OUT   0x05
#define PORT_DDR   0x06
#define PORT_IN    0x07

#define PORT_POWER 0x08

#define   FLAG_SAVE_PORT    0x01                      /* Восстановить состояние порта */
#define   FLAG_SAVE_POWER   0x02                      /* Восстановить состояние И.У.  */

class dg2313w {
public:
        dg2313w (OneWire &wire);                      /* Конструктор класса */
        bool power (bool enable);                     /* Включить/отключить имеющееся  в устройстве реле. */
        bool readROM (byte* addr);                    /* Прочитать адрес устройства (если устройство одно на шине)  */
        void select (byte* addr);                     /* Выбрать устройство на шине с адресом.
                                                          Обмен с устройством не происходит просто запоминаем адрес устройства с которым будем работать.
                                                          Если данная функция нигде не применена будут выбраны все устройства на шине */
        bool connect ();                              /* Подсоеденится к устройству, адрес надо задать ранее в функции select. функция вернет false только
                                                         в случае если на шине нет вообше ни одного устройства, в любом другом true, даже если нужного нам
                                                         устройства нет на шине.*/
                                                
        bool set (byte address,byte value);           /* Записать  байт (value) по адресу (address), в случае удачи вернет true */
        bool get (byte address,byte &value);          /* Прочитать байт (value) по адресу (address), в случае удачи вернет true */
private :
        OneWire *wire;
        byte current [8]; 
        bool skip = true;

};

#endif //DG2313W
